#
# Copyright (C) 2008 by Juergen Beisert
#
# See CREDITS for details about who has contributed to this project.
#
# For further information about the PTXdist project and license conditions
# see the README file.
#

#
# We provide this package only for the MPC5200-IO platform
# (no other platform comes with a loadable FPGA)
#
ifeq ($(PTXCONF_PLATFORM), phyCORE-MPC5200B-IO)
PACKAGES-$(PTXCONF_FPGA) += fpga

ifdef PTXCONF_FPGA
$(STATEDIR)/kernel.targetinstall.post: $(STATEDIR)/fpga.targetinstall
endif

endif

#
# Paths and names and versions
#
FPGA_VERSION	:= 1.0.0
FPGA		:= fpga-$(FPGA_VERSION)
FPGA_URL	:= file://$(PTXDIST_WORKSPACE)/local_src/$(FPGA)
FPGA_SOURCE	:= $(SRCDIR)/$(FPGA)
FPGA_DIR	:= $(BUILDDIR)/$(FPGA)


# ----------------------------------------------------------------------------
# Get
# ----------------------------------------------------------------------------

fpga_get: $(STATEDIR)/fpga.get

 $(STATEDIR)/fpga.get: $(fpga_get_deps_default)
	@$(call targetinfo, $@)
	@$(call touch, $@)

$(FPGA_SOURCE):
	@$(call targetinfo, $@)
	@$(call get, FPGA)

# ----------------------------------------------------------------------------
# Extract
# ----------------------------------------------------------------------------

fpga_extract: $(STATEDIR)/fpga.extract

$(STATEDIR)/fpga.extract: $(fpga_extract_deps_default)
	@$(call targetinfo, $@)
	@$(call clean, $(FPGA_DIR))
	@$(call extract, FPGA)
	@$(call patchin, FPGA)
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Prepare
# ----------------------------------------------------------------------------

fpga_prepare: $(STATEDIR)/fpga.prepare

FPGA_PATH	:= PATH=$(CROSS_PATH)
FPGA_ENV 	:= $(CROSS_ENV)

$(STATEDIR)/fpga.prepare: $(fpga_prepare_deps_default)
	@$(call targetinfo, $@)
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Compile
# ----------------------------------------------------------------------------

fpga_compile: $(STATEDIR)/fpga.compile

$(STATEDIR)/fpga.compile: $(fpga_compile_deps_default)
	@$(call targetinfo, $@)
	cd $(FPGA_DIR) && $(KERNEL_PATH) $(KERNEL_ENV) \
		$(MAKE) $(KERNEL_MAKEVARS)
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Install
# ----------------------------------------------------------------------------

fpga_install: $(STATEDIR)/fpga.install

$(STATEDIR)/fpga.install: $(fpga_install_deps_default)
	@$(call targetinfo, $@)
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Target-Install
# ----------------------------------------------------------------------------

fpga_targetinstall: $(STATEDIR)/fpga.targetinstall

$(STATEDIR)/fpga.targetinstall: $(fpga_targetinstall_deps_default)
	@$(call targetinfo, $@)
	cd $(FPGA_DIR) && $(KERNEL_PATH) $(KERNEL_ENV) $(MAKE) \
		$(KERNEL_MAKEVARS) modules_install
ifdef PTXCONF_FPGA_FIRMWARE

	@$(call install_init, fpga)
	@$(call install_fixup, fpga,PACKAGE,fpga)
	@$(call install_fixup, fpga,PRIORITY,optional)
	@$(call install_fixup, fpga,VERSION,1.0.0)
	@$(call install_fixup, fpga,SECTION,base)
	@$(call install_fixup, fpga,AUTHOR,"Juergen Beisert <j.beisert\@pengutronix.de>")
	@$(call install_fixup, fpga,DEPENDS,)
	@$(call install_fixup, fpga,DESCRIPTION,missing)
	@$(call install_copy, fpga, 0, 0, 0644, $(PTXDIST_WORKSPACE)/projectroot/lib/firmware/MPC_to_WBSlave.rbf, /lib/firmware/MPC_to_WBSlave.rbf, n)
	@$(call install_finish, fpga)
endif
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Clean
# ----------------------------------------------------------------------------

fpga_clean:
	rm -rf $(STATEDIR)/fpga.*
	cd $(FPGA_DIR) && $(KERNEL_ENV) $(KERNEL_PATH) $(MAKE) clean

# vim: syntax=make
